aboutsummaryrefslogtreecommitdiffstats
path: root/src/gallium/drivers/radeon/AMDILSIDevice.h
diff options
context:
space:
mode:
Diffstat (limited to 'src/gallium/drivers/radeon/AMDILSIDevice.h')
-rw-r--r--src/gallium/drivers/radeon/AMDILSIDevice.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/src/gallium/drivers/radeon/AMDILSIDevice.h b/src/gallium/drivers/radeon/AMDILSIDevice.h
index 91ed97f183f..6a684cb6095 100644
--- a/src/gallium/drivers/radeon/AMDILSIDevice.h
+++ b/src/gallium/drivers/radeon/AMDILSIDevice.h
@@ -25,21 +25,21 @@ namespace llvm {
// SI generation of devices and their respective sub classes
//===---------------------------------------------------------------------===//
// The AMDILSIDevice is the base class for all Northern Island series of
// cards. It is very similiar to the AMDILEvergreenDevice, with the major
// exception being differences in wavefront size and hardware capabilities. The
// SI devices are all 64 wide wavefronts and also add support for signed 24 bit
// integer operations
- class AMDILSIDevice : public AMDILEvergreenDevice {
+ class AMDGPUSIDevice : public AMDGPUEvergreenDevice {
public:
- AMDILSIDevice(AMDGPUSubtarget*);
- virtual ~AMDILSIDevice();
+ AMDGPUSIDevice(AMDGPUSubtarget*);
+ virtual ~AMDGPUSIDevice();
virtual size_t getMaxLDSSize() const;
virtual uint32_t getGeneration() const;
virtual std::string getDataLayout() const;
protected:
- }; // AMDILSIDevice
+ }; // AMDGPUSIDevice
} // namespace llvm
#endif // _AMDILSIDEVICE_H_
@@ -25,21 +25,21 @@ namespace llvm {
// SI generation of devices and their respective sub classes
//===---------------------------------------------------------------------===//
-// The AMDILSIDevice is the base class for all Northern Island series of
-// cards. It is very similiar to the AMDILEvergreenDevice, with the major
+// The AMDGPUSIDevice is the base class for all Northern Island series of
+// cards. It is very similiar to the AMDGPUEvergreenDevice, with the major
// exception being differences in wavefront size and hardware capabilities. The
// SI devices are all 64 wide wavefronts and also add support for signed 24 bit